# Wii-Rom-Downloader

## Description
This tool is made for automatically downloading your favorite roms for
your wii/emulator and naming it to the right id so your real wii will recognize 
it! It also converts rvz formats to wbfs for real hardware!

## Instruction
Just run this command to install the tool or download binaries from releases!
(Make sure you have python installed!)
```shell
pip install wii-roms-tool
```
To start the menu type:
```shell
wii-roms-tool
```

## Providers
In my tool there are currently 2 options:
Romsfun and Vimms Lair!
1. Romsfun: Better option for availability but needs to be converted for real hardware!
2. Vimms Lair: Easier ID finding and has wbfs files! But big games are missing currently!

## ⚠️ Disclaimer
I provide this tool for educational and informational purposes only.
You are solely responsible for how you use it.
Any actions taken using this tool are entirely your own responsibility.
I do not condone or support illegal use.

## Support 
If you need any help you can open an issue or contact me via discord ``Tmaster055``!